/***************************************************************************
 *   Copyright (C) 2006 by Jens Dagerbo                                    *
 *   jens.dagerbo@swipnet.se                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef PLUGINSELECTDIALOG_H
#define PLUGINSELECTDIALOG_H

#include "pluginselectdialogbase.h"

class PluginController;

class PluginSelectDialog : public PluginSelectDialogBase
{
	TQ_OBJECT
  

public:
	PluginSelectDialog( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
	~PluginSelectDialog();

	TQStringList unselectedPluginNames();

private:
	void init();

protected slots:
	virtual void saveAsDefault();
    void itemSelected( TQListViewItem * );
    void openURL( const TQString & );

};

#endif
